@@ -121,7 +121,7 @@ def GD_dialog_show(button3):
     dialog.destroy()
     
 
-class ACCplugin(hildondesktop.HomePluginItem):
+class levelplugin(hildondesktop.HomePluginItem):
     def __init__(self):
         hildondesktop.HomePluginItem.__init__(self)
 
@@ -223,4 +223,6 @@ class ACCplugin(hildondesktop.HomePluginItem):
         f.close()
         return coords
 
-hd_plugin_type = ACCplugin
\ No newline at end of file
+def hd_plugin_get_objects():
+	plugin = levelplugin()
+	return [plugin]
\ No newline at end of file
